==> iReport-0.5.1-src.zip: iReport-0.5.1-src/src/it/businesslogic/ireport/chart/CategorySeries.java <==
/*
 * CategorySeries.java
 *
 * Created on 17 agosto 2005, 10.56
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class CategorySeries {
    
    private String seriesExpression = "";
    private String categoryExpression = "";
    private String valueExpression = "";
    private String labelExpression = "";
    
    /** Creates a new instance of CategorySeries */
    public CategorySeries() {
    }

    public String getSeriesExpression() {
        return seriesExpression;
    }

    public void setSeriesExpression(String seriesExpression) {
        this.seriesExpression = seriesExpression;
    }

    public String getCategoryExpression() {
        return categoryExpression;
    }

    public void setCategoryExpression(String categoryExpression) {
        this.categoryExpression = categoryExpression;
    }

    public String getValueExpression() {
        return valueExpression;
    }

    public void setValueExpression(String valueExpression) {
        this.valueExpression = valueExpression;
    }

    public String getLabelExpression() {
        return labelExpression;
    }

    public void setLabelExpression(String labelExpression) {
        this.labelExpression = labelExpression;
    }
    
    public String toString()
    {
        String str = getSeriesExpression();
        if (str == null) str = "";
        if (str.length() > 50) str = str.substring(0,30);
        
        return "Category series [" + str + "]";
    }
    
    public CategorySeries cloneMe()
    {
        CategorySeries cs = new CategorySeries();
        cs.setSeriesExpression( this.getSeriesExpression());
        cs.setCategoryExpression( this.getCategoryExpression());
        cs.setValueExpression( this.getValueExpression());
        cs.setLabelExpression( this.getLabelExpression());
        
        return cs;
    }
    
}

==> iReport-1.2.6-src.zip: iReport-1.2.6-src/src/it/businesslogic/ireport/chart/CategorySeries.java <==
/*
 * CategorySeries.java
 *
 * Created on 17 agosto 2005, 10.56
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class CategorySeries {
    
    private String seriesExpression = "";
    private String categoryExpression = "";
    private String valueExpression = "";
    private String labelExpression = "";
    private SectionItemHyperlink sectionItemHyperlink = new SectionItemHyperlink();
    
    /** Creates a new instance of CategorySeries */
    public CategorySeries() {
    }

    public String getSeriesExpression() {
        return seriesExpression;
    }

    public void setSeriesExpression(String seriesExpression) {
        this.seriesExpression = seriesExpression;
    }

    public String getCategoryExpression() {
        return categoryExpression;
    }

    public void setCategoryExpression(String categoryExpression) {
        this.categoryExpression = categoryExpression;
    }

    public String getValueExpression() {
        return valueExpression;
    }

    public void setValueExpression(String valueExpression) {
        this.valueExpression = valueExpression;
    }

    public String getLabelExpression() {
        return labelExpression;
    }

    public void setLabelExpression(String labelExpression) {
        this.labelExpression = labelExpression;
    }
    
    public String toString()
    {
        String str = getSeriesExpression();
        if (str == null) str = "";
        if (str.length() > 50) str = str.substring(0,30);
        
        return "Category series [" + str + "]";
    }
    
    public CategorySeries cloneMe()
    {
        CategorySeries cs = new CategorySeries();
        cs.setSeriesExpression( this.getSeriesExpression());
        cs.setCategoryExpression( this.getCategoryExpression());
        cs.setValueExpression( this.getValueExpression());
        cs.setLabelExpression( this.getLabelExpression());
        cs.setSectionItemHyperlink( this.getSectionItemHyperlink().cloneMe());
        
        return cs;
    }

    public SectionItemHyperlink getSectionItemHyperlink() {
        return sectionItemHyperlink;
    }

    public void setSectionItemHyperlink(SectionItemHyperlink sectionItemHyperlink) {
        this.sectionItemHyperlink = sectionItemHyperlink;
    }
    
}
